.. _sync_client:

.. currentmodule:: akismet


The synchronous Akismet client
==============================


.. autoclass:: SyncClient

   .. automethod:: validated_client
   .. automethod:: comment_check
   .. automethod:: key_sites
   .. automethod:: submit_ham
   .. automethod:: submit_spam
   .. automethod:: usage_limit
   .. automethod:: verify_key
